@@ -1,17 +1,17 @@
 /*
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
-  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "messagefactoryng.h"
 
+#include "draftstatus/draftstatus.h"
 #include "messagefactoryforwardjob.h"
 #include "messagefactoryreplyjob.h"
 #include "settings/messagecomposersettings.h"
-#include "draftstatus/draftstatus.h"
 #include <MessageComposer/Util>
 
 #include <KCursorSaver>
@@ -21,7 +21,6 @@
 
 #include "helper/messagehelper.h"
 #include "messagecomposer_debug.h"
-#include <KCharsets>
 #include <KEmailAddress>
 #include <KLocalizedString>
 #include <KMime/DateFormatter>
@@ -222,7 +221,6 @@ void MessageFactoryNG::createReplyAsync()
                 // Doesn't seem to be a mailing list.
                 auto originalFromList = mOrigMsg->from()->mailboxes();
                 auto originalToList = mOrigMsg->to()->mailboxes();
-
                 if (mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalFromList))
                     && !mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))) {
                     // Sender seems to be one of our own identities and recipient is not,
@@ -232,7 +230,10 @@ void MessageFactoryNG::createReplyAsync()
                 } else {
                     // "Normal" case:  reply to sender.
                     toList = stripMyAddressesFromAddressList(mOrigMsg->to()->mailboxes(), mIdentityManager);
-                    toList += authorMailboxes(mOrigMsg, mMailingListAddresses);
+                    const auto authors = authorMailboxes(mOrigMsg, mMailingListAddresses);
+                    if (!mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(authors))) {
+                        toList += authors;
+                    }
                 }
             }
 
@@ -928,19 +929,20 @@ void MessageFactoryNG::applyCharset(const KMime::Message::Ptr msg)
 {
     if (MessageComposer::MessageComposerSettings::forceReplyCharset()) {
         // first convert the body from its current encoding to unicode representation
-        QTextCodec *bodyCodec = KCharsets::charsets()->codecForName(QString::fromLatin1(msg->contentType()->charset()));
+        QTextCodec *bodyCodec = QTextCodec::codecForName(msg->contentType()->charset());
         if (!bodyCodec) {
-            bodyCodec = KCharsets::charsets()->codecForName(QStringLiteral("UTF-8"));
+            bodyCodec = QTextCodec::codecForName("UTF-8");
+            if (!bodyCodec) {
+                bodyCodec = QTextCodec::codecForLocale();
+            }
         }
-
         const QString body = bodyCodec->toUnicode(msg->body());
 
         // then apply the encoding of the original message
-        msg->contentType()->setCharset(mOrigMsg->contentType()->charset());
-
-        QTextCodec *codec = KCharsets::charsets()->codecForName(QString::fromLatin1(msg->contentType()->charset()));
+        QTextCodec *codec = QTextCodec::codecForName(mOrigMsg->contentType()->charset());
         if (!codec) {
-            qCCritical(MESSAGECOMPOSER_LOG) << "Could not get text codec for charset" << msg->contentType()->charset();
+            qCCritical(MESSAGECOMPOSER_LOG) << "Could not get text codec for charset" << mOrigMsg->contentType()->charset();
+            // Don't touch the message
         } else if (!codec->canEncode(body)) { // charset can't encode body, fall back to preferred
             const QStringList charsets = MessageComposer::MessageComposerSettings::preferredCharsets();
 
@@ -955,9 +957,14 @@ void MessageFactoryNG::applyCharset(const KMime::Message::Ptr msg)
                 fallbackCharset = "UTF-8";
             }
 
-            codec = KCharsets::charsets()->codecForName(QString::fromLatin1(fallbackCharset));
+            codec = QTextCodec::codecForName(fallbackCharset);
+            if (!codec) {
+                codec = QTextCodec::codecForLocale();
+            }
+            msg->contentType()->setCharset(codec->name());
             msg->setBody(codec->fromUnicode(body));
         } else {
+            msg->contentType()->setCharset(mOrigMsg->contentType()->charset());
             msg->setBody(codec->fromUnicode(body));
         }
     }
