@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,9 +12,7 @@
 #include <MessageComposer/ConvertSnippetVariablesJob>
 using namespace MessageComposer;
 
-PluginComposerInterface::PluginComposerInterface()
-{
-}
+PluginComposerInterface::PluginComposerInterface() = default;
 
 PluginComposerInterface::~PluginComposerInterface()
 {
@@ -32,6 +30,11 @@ QString PluginComposerInterface::subject() const
     return mComposerViewInterface->subject();
 }
 
+QString PluginComposerInterface::replyTo() const
+{
+    return mComposerViewInterface->replyTo();
+}
+
 QString PluginComposerInterface::to() const
 {
     return mComposerViewInterface->to();
