@@ -9,8 +9,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef RECIPIENTSEDITORSIDEWIDGET_H
-#define RECIPIENTSEDITORSIDEWIDGET_H
+#pragma once
 
 #include "recipientseditor.h"
 
@@ -54,5 +53,3 @@ private:
     mutable MessageComposer::KWindowPositioner *mPickerPositioner = nullptr;
 };
 }
-
-#endif // RECIPIENTSEDITORSIDEWIDGET_H
