@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,18 +8,18 @@
 
 #include <QCommandLineParser>
 #include <QCoreApplication>
+#include <QDebug>
 #include <QFile>
 #include <QStandardPaths>
-#include <QDebug>
 
 CheckSignature::CheckSignature(const QString &fileName, QObject *parent)
     : QObject(parent)
 {
     mQcaInitializer = new QCA::Initializer(QCA::Practical, 64);
-    auto *job = new MessageViewer::DKIMCheckSignatureJob(this);
+    auto job = new MessageViewer::DKIMCheckSignatureJob(this);
     connect(job, &MessageViewer::DKIMCheckSignatureJob::result, this, &CheckSignature::slotResult);
 
-    auto *msg = new KMime::Message;
+    auto msg = new KMime::Message;
     QFile file(fileName);
     if (file.open(QIODevice::ReadOnly)) {
         msg->setContent(file.readAll());
@@ -48,8 +48,7 @@ int main(int argc, char **argv)
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[file]"),
-                                        QStringLiteral("File containing an email")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[file]"), QStringLiteral("File containing an email")));
 
     parser.process(app);
 
