@@ -7,7 +7,6 @@
 #pragma once
 
 #include "webengineviewer_export.h"
-#include <QObject>
 #include <QWebEngineScript>
 
 class QWebEngineProfile;
@@ -17,12 +16,8 @@ namespace WebEngineViewer
  * @brief The WebEngineManageScript class
  * @author Laurent Montel <montel@kde.org>
  */
-class WEBENGINEVIEWER_EXPORT WebEngineManageScript : public QObject
+struct WEBENGINEVIEWER_EXPORT WebEngineManageScript
 {
-    Q_OBJECT
-public:
-    explicit WebEngineManageScript(QObject *parent = nullptr);
-    ~WebEngineManageScript() override;
     static quint32 scriptWordId()
     {
         return QWebEngineScript::UserWorld + 1;
